@@ -235,12 +235,13 @@ func TestHelmRender(t *testing.T) {
 	MarkIntegrationTest(t, CanRunWithoutGcp)
 
 	tests := []struct {
-		description  string
-		dir          string
-		args         []string
-		builds       []graph.Artifact
-		helmReleases []latest.HelmRelease
-		expectedOut  string
+		description      string
+		dir              string
+		args             []string
+		builds           []graph.Artifact
+		helmReleases     []latest.HelmRelease
+		expectedOut      string
+		withoutBuildJSON bool
 	}{
 		{
 			description: "Bare bones render",
@@ -364,12 +365,47 @@ spec:
               number: 80
         path: /
         pathType: ImplementationSpecific
+`,
+		}, {
+			description:      "Template with Release.namespace set from skaffold.yaml file",
+			dir:              "testdata/helm-namespace",
+			withoutBuildJSON: true,
+			expectedOut: `apiVersion: apps/v1
+kind: Deployment
+metadata:
+  labels:
+    app: skaffold-helm
+    skaffold.dev/run-id: phony-run-id
+  name: skaffold-helm
+  namespace: helm-namespace
+spec:
+  replicas: 2
+  selector:
+    matchLabels:
+      app: skaffold-helm
+  template:
+    metadata:
+      labels:
+        app: skaffold-helm
+        skaffold.dev/run-id: phony-run-id
+    spec:
+      containers:
+      - image: skaffold-helm:latest
+        name: skaffold-helm
 `,
 		},
 	}
 	for _, test := range tests {
 		t.Run(test.description, func(t *testing.T) {
-			out := skaffold.Render(append([]string{"--build-artifacts=builds.out.json", "--default-repo=", "--label=skaffold.dev/run-id=phony-run-id"}, test.args...)...).InDir(test.dir).RunOrFailOutput(t)
+			MarkIntegrationTest(t, CanRunWithoutGcp)
+
+			args := []string{"--default-repo=", "--label=skaffold.dev/run-id=phony-run-id"}
+			if !test.withoutBuildJSON {
+				args = append(args, "--build-artifacts=builds.out.json")
+			}
+			args = append(args, test.args...)
+
+			out := skaffold.Render(args...).InDir(test.dir).RunOrFailOutput(t)
 
 			testutil.CheckDeepEqual(t, test.expectedOut, string(out))
 		})
