@@ -24,6 +24,7 @@ import (
 	"testing"
 	"time"
 
+	"github.com/google/uuid"
 	"k8s.io/apimachinery/pkg/util/wait"
 
 	"github.com/GoogleContainerTools/skaffold/integration/skaffold"
@@ -279,7 +280,7 @@ func TestRunTailTolerateFailuresUntilDeadline(t *testing.T) {
 
 			args := append(test.args, "--tail")
 			out := skaffold.Run(args...).InDir(test.dir).InNs(ns.Name).WithEnv(test.env).RunLive(t)
-			defer skaffold.Delete().InDir(test.dir).WithEnv(test.env).RunOrFail(t)
+			defer skaffold.Delete().InDir(test.dir).InNs(ns.Name).WithEnv(test.env).Run(t)
 			WaitForLogs(t, out, test.targetLogOne)
 			WaitForLogs(t, out, test.targetLogTwo)
 		})
@@ -315,8 +316,6 @@ func TestRunRenderOnly(t *testing.T) {
 }
 
 func TestRunGCPOnly(t *testing.T) {
-	MarkIntegrationTest(t, NeedsGcp)
-
 	tests := []struct {
 		description string
 		dir         string
@@ -341,9 +340,9 @@ func TestRunGCPOnly(t *testing.T) {
 		},
 		{
 			description: "Google Cloud Build with source artifact dependencies",
-			dir:         "examples/microservices",
+			dir:         "testdata/multi-config-pods",
 			args:        []string{"-p", "gcb"},
-			deployments: []string{"leeroy-app", "leeroy-web"},
+			pods:        []string{"module1", "module2"},
 		},
 		// {
 		//	description: "Google Cloud Build with Kaniko",
@@ -394,8 +393,11 @@ func TestRunGCPOnly(t *testing.T) {
 			continue // buildpacks doesn't support arm64 builds, so skip run on these clusters
 		}
 		t.Run(test.description, func(t *testing.T) {
+			MarkIntegrationTest(t, NeedsGcp)
 			ns, client := SetupNamespace(t)
 
+			test.args = append(test.args, "--tag", uuid.New().String())
+
 			skaffold.Run(test.args...).InDir(test.dir).InNs(ns.Name).RunOrFail(t)
 
 			client.WaitForPodsReady(test.pods...)
@@ -574,3 +576,32 @@ func TestRunNoOptFlags(t *testing.T) {
 		WaitForLogs(t, out, test.targetLog)
 	})
 }
+
+func TestRunKubectlDefaultNamespace(t *testing.T) {
+	tests := []struct {
+		description       string
+		namespaceToCreate string
+		projectDir        string
+		podName           string
+		envVariable       string
+	}{
+		{
+			description:       "run with defaultNamespace when namespace exists in cluster",
+			namespaceToCreate: "namespace-test",
+			projectDir:        "testdata/kubectl-with-default-namespace",
+			podName:           "getting-started",
+			envVariable:       "ENV1",
+		},
+	}
+
+	for _, test := range tests {
+		testutil.Run(t, test.description, func(t *testutil.T) {
+			MarkIntegrationTest(t.T, CanRunWithoutGcp)
+			ns, client := SetupNamespace(t.T)
+			t.SetEnvs(map[string]string{test.envVariable: ns.Name})
+			skaffold.Run().InDir(test.projectDir).RunOrFail(t.T)
+			pod := client.GetPod(test.podName)
+			t.CheckNotNil(pod)
+		})
+	}
+}
