@@ -18,6 +18,7 @@ package diag
 
 import (
 	"context"
+	"fmt"
 	"testing"
 
 	"github.com/google/go-cmp/cmp"
@@ -33,12 +34,20 @@ type mockValidator struct {
 	listOptions metav1.ListOptions
 }
 
+type mockErrValidator struct {
+	*mockValidator
+}
+
 func (m *mockValidator) Validate(_ context.Context, ns string, opts metav1.ListOptions) ([]validator.Resource, error) {
 	m.ns = append(m.ns, ns)
 	m.listOptions = opts
 	return nil, nil
 }
 
+func (e *mockErrValidator) Validate(_ context.Context, ns string, opts metav1.ListOptions) ([]validator.Resource, error) {
+	return nil, fmt.Errorf("error")
+}
+
 func TestRun(t *testing.T) {
 	tests := []struct {
 		description string
@@ -50,14 +59,14 @@ func TestRun(t *testing.T) {
 			description: "multiple namespaces with an empty namespace and no labels",
 			ns:          []string{"foo", "bar", ""},
 			expected: &mockValidator{
-				ns:          []string{"foo", "bar"},
+				ns:          []string{"foo", "bar", ""},
 				listOptions: metav1.ListOptions{},
 			},
 		},
 		{
 			description: "empty namespaces no labels",
 			ns:          []string{""},
-			expected:    &mockValidator{ns: nil},
+			expected:    &mockValidator{ns: []string{""}},
 		},
 		{
 			description: "multiple namespaces and multiple labels",
@@ -87,3 +96,33 @@ func TestRun(t *testing.T) {
 		})
 	}
 }
+
+func TestRunErr(t *testing.T) {
+	tests := []struct {
+		description    string
+		shouldErr      bool
+		labels         map[string]string
+		ns             []string
+		expectedErrMsg string
+	}{
+		{
+			description: "handles error",
+			shouldErr:   true,
+			labels: map[string]string{
+				"skaffold": "session",
+			},
+			ns:             []string{"foo"},
+			expectedErrMsg: "following errors occurred error\n",
+		},
+	}
+
+	for _, test := range tests {
+		testutil.Run(t, test.description, func(t *testutil.T) {
+			d := New(test.ns)
+			m := &mockErrValidator{}
+			d = d.WithValidators([]validator.Validator{m})
+			_, err := d.Run(context.Background())
+			t.CheckErrorAndDeepEqual(test.shouldErr, err, test.expectedErrMsg, err.Error())
+		})
+	}
+}
