@@ -32,7 +32,7 @@ import (
 )
 
 var (
-	dependencyCache = util.NewSyncStore()
+	dependencyCache = util.NewSyncStore[[]string]()
 )
 
 // BuildConfig encapsulates all the build configuration required for performing a dockerbuild.
@@ -78,9 +78,9 @@ func GetDependencies(ctx context.Context, buildCfg BuildConfig, cfg Config) ([]s
 	if err != nil {
 		return nil, fmt.Errorf("normalizing dockerfilePath path: %w", err)
 	}
-	result := getDependencies(ctx, buildCfg.workspace, buildCfg.dockerfilePath, absDockerfilePath, buildCfg.args, cfg)
-	dependencyCache.Store(buildCfg.artifact, result)
-	return resultPair(result)
+	result, err := getDependencies(ctx, buildCfg.workspace, buildCfg.dockerfilePath, absDockerfilePath, buildCfg.args, cfg)
+	dependencyCache.Store(buildCfg.artifact, result, err)
+	return result, err
 }
 
 // GetDependencies finds the sources dependency for the given docker artifact.
@@ -103,21 +103,9 @@ func GetDependenciesCached(ctx context.Context, buildCfg BuildConfig, cfg Config
 		return nil, fmt.Errorf("normalizing dockerfilePath path: %w", err)
 	}
 
-	deps := dependencyCache.Exec(buildCfg.artifact, func() interface{} {
+	return dependencyCache.Exec(buildCfg.artifact, func() ([]string, error) {
 		return getDependencies(ctx, buildCfg.workspace, buildCfg.dockerfilePath, absDockerfilePath, buildCfg.args, cfg)
 	})
-	return resultPair(deps)
-}
-
-func resultPair(deps interface{}) ([]string, error) {
-	switch t := deps.(type) {
-	case error:
-		return nil, t
-	case []string:
-		return t, nil
-	default:
-		return nil, fmt.Errorf("internal error when retrieving cache result of type %T", t)
-	}
 }
 
 func resultPairForDockerCopyFromTo(deps interface{}) (map[string][]string, error) {
@@ -131,23 +119,23 @@ func resultPairForDockerCopyFromTo(deps interface{}) (map[string][]string, error
 	}
 }
 
-func getDependencies(ctx context.Context, workspace string, dockerfilePath string, absDockerfilePath string, buildArgs map[string]*string, cfg Config) interface{} {
+func getDependencies(ctx context.Context, workspace string, dockerfilePath string, absDockerfilePath string, buildArgs map[string]*string, cfg Config) ([]string, error) {
 	// If the Dockerfile doesn't exist, we can't compute the dependency.
 	// But since we know the Dockerfile is a dependency, let's return a list
 	// with only that file. It makes errors down the line more actionable
 	// than returning an error now.
 	if _, err := os.Stat(absDockerfilePath); os.IsNotExist(err) {
-		return []string{dockerfilePath}
+		return []string{dockerfilePath}, nil
 	}
 
 	fts, err := ReadCopyCmdsFromDockerfile(ctx, false, absDockerfilePath, workspace, buildArgs, cfg)
 	if err != nil {
-		return err
+		return nil, err
 	}
 
 	excludes, err := readDockerignore(workspace, absDockerfilePath)
 	if err != nil {
-		return fmt.Errorf("reading .dockerignore: %w", err)
+		return nil, fmt.Errorf("reading .dockerignore: %w", err)
 	}
 
 	deps := make([]string, 0, len(fts))
@@ -157,7 +145,7 @@ func getDependencies(ctx context.Context, workspace string, dockerfilePath strin
 
 	files, err := WalkWorkspace(workspace, excludes, deps)
 	if err != nil {
-		return fmt.Errorf("walking workspace: %w", err)
+		return nil, fmt.Errorf("walking workspace: %w", err)
 	}
 
 	// Always add dockerfile even if it's .dockerignored. The daemon will need it anyways.
@@ -176,7 +164,7 @@ func getDependencies(ctx context.Context, workspace string, dockerfilePath strin
 	}
 	sort.Strings(dependencies)
 
-	return dependencies
+	return dependencies, nil
 }
 
 func getDependenciesByDockerCopyFromTo(ctx context.Context, workspace string, dockerfilePath string, absDockerfilePath string, buildArgs map[string]*string, cfg Config) interface{} {
