@@ -17,6 +17,8 @@ limitations under the License.
 package analyze
 
 import (
+	"context"
+
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/kubernetes"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema"
 )
@@ -27,7 +29,7 @@ type kubeAnalyzer struct {
 	kubernetesManifests []string
 }
 
-func (k *kubeAnalyzer) analyzeFile(filePath string) error {
+func (k *kubeAnalyzer) analyzeFile(ctx context.Context, filePath string) error {
 	if kubernetes.IsKubernetesManifest(filePath) && !schema.IsSkaffoldConfig(filePath) {
 		k.kubernetesManifests = append(k.kubernetesManifests, filePath)
 	}
