@@ -213,17 +213,15 @@ func TestDoInit(t *testing.T) {
 			},
 		},
 		{
-			name: "helm fails",
-			dir:  "testdata/init/helm-deployment",
+			name:       "helm init",
+			dir:        "testdata/init/helm-deployment",
+			shouldSkip: true, // Github Actions CI runners don't have helm. This test should mock helm.
 			config: initconfig.Config{
+				Force: true,
 				Opts: config.SkaffoldOptions{
 					ConfigurationFile: "skaffold.yaml.out",
 				},
 			},
-			expectedError: `Projects set up to deploy with helm must be manually configured.
-
-See https://skaffold.dev/docs/pipeline-stages/deployers/helm/ for a detailed guide on setting your project up with skaffold.`,
-			expectedExitCode: 1,
 		},
 	}
 	for _, test := range tests {
