@@ -134,7 +134,11 @@ func getConfigs(ctx context.Context, cfgOpts configOpts, opts config.SkaffoldOpt
 	// add profiles to record and validate that config names are unique if specified
 	seen := make(map[string]bool)
 	for _, cfg := range parsed {
-		config := cfg.(*latest.SkaffoldConfig)
+		config, ok := cfg.(*latest.SkaffoldConfig)
+		if !ok {
+			return nil, nil, sErrors.SkaffoldConfigUpgradeErr(cfg.GetVersion(), latest.Version)
+		}
+
 		for _, profile := range config.Profiles {
 			if !stringslice.Contains(r.allProfiles, profile.Name) {
 				r.allProfiles = append(r.allProfiles, profile.Name)
@@ -153,7 +157,11 @@ func getConfigs(ctx context.Context, cfgOpts configOpts, opts config.SkaffoldOpt
 
 	var configs SkaffoldConfigSet
 	for i, cfg := range parsed {
-		config := cfg.(*latest.SkaffoldConfig)
+		config, ok := cfg.(*latest.SkaffoldConfig)
+		if !ok {
+			return nil, nil, sErrors.SkaffoldConfigUpgradeErr(cfg.GetVersion(), latest.Version)
+		}
+
 		processed, err := processEachConfig(ctx, config, cfgOpts, opts, r, i, fieldsOverrodeByProfile)
 		if err != nil {
 			return nil, nil, err
