@@ -26,7 +26,7 @@ import (
 )
 
 // This config version is not yet released, it is SAFE TO MODIFY the structs in this file.
-const Version string = "skaffold/v3"
+const Version string = "skaffold/v4beta1"
 
 // NewSkaffoldConfig creates a SkaffoldConfig
 func NewSkaffoldConfig() util.VersionedConfig {
@@ -594,6 +594,9 @@ type Generate struct {
 	// RawK8s defines the raw kubernetes resources.
 	RawK8s []string `yaml:"rawYaml,omitempty" skaffold:"filepath"`
 
+	// RemoteManifests lists Kubernetes manifests in remote clusters.
+	RemoteManifests []RemoteManifest `yaml:"remoteManifests,omitempty"`
+
 	// Kustomize defines the paths to be modified with kustomize, along with extra
 	// flags to be passed to kustomize.
 	Kustomize *Kustomize `yaml:"kustomize,omitempty"`
@@ -611,6 +614,17 @@ type Generate struct {
 	LifecycleHooks RenderHooks `yaml:"hooks,omitempty"`
 }
 
+// RemoteManifest defines the paths to be modified with kustomize, along with
+// extra flags to be passed to kustomize.
+type RemoteManifest struct {
+	// Manifest specifies the Kubernetes manifest in the remote cluster.
+	Manifest string `yaml:"manifest,omitempty"`
+
+	// KubeContext is the Kubernetes context that Skaffold should deploy to.
+	// For example: `minikube`.
+	KubeContext string `yaml:"kubeContext,omitempty"`
+}
+
 // Kustomize defines the paths to be modified with kustomize, along with
 // extra flags to be passed to kustomize.
 type Kustomize struct {
@@ -689,6 +703,11 @@ type DeployConfig struct {
 	// StatusCheckDeadlineSeconds *beta* is the deadline for deployments to stabilize in seconds.
 	StatusCheckDeadlineSeconds int `yaml:"statusCheckDeadlineSeconds,omitempty"`
 
+	// TolerateFailuresUntilDeadline configures the Skaffold "status-check" to tolerate failures
+	// (flapping deployments, etc.) until the statusCheckDeadlineSeconds duration or k8s object
+	// timeouts such as progressDeadlineSeconds, etc.
+	TolerateFailuresUntilDeadline bool `yaml:"tolerateFailuresUntilDeadline,omitempty"`
+
 	// KubeContext is the Kubernetes context that Skaffold should deploy to.
 	// For example: `minikube`.
 	KubeContext string `yaml:"kubeContext,omitempty"`
@@ -856,6 +875,10 @@ type HelmRelease struct {
 	// Ignored for `remoteChart`.
 	SkipBuildDependencies bool `yaml:"skipBuildDependencies,omitempty"`
 
+	// SkipTests should ignore helm test during manifests generation.
+	// Defaults to `false`
+	SkipTests bool `yaml:"skipTests,omitempty"`
+
 	// UseHelmSecrets instructs skaffold to use secrets plugin on deployment.
 	UseHelmSecrets bool `yaml:"useHelmSecrets,omitempty"`
 
